from setuptools import setup

setup(name='probabilityLK',
      version='0.1',
      description='Gaussian distributions',
      packages=['probabilityLK'],
      author='Lakshya Kwatra',
      author_email='lkwatra2@gmail.com',
      zip_safe=False)
